<?php

namespace Drupal\solrlog\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Solr log settings form.
 */
class SolrSettingsForm extends ConfigFormBase {

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'solrlog_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['solrlog.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $options = [];
    foreach ($this->entityTypeManager
      ->getStorage('search_api_server')
      ->loadByProperties(['backend' => 'search_api_solr']) as $server) {
      $options[$server->id()] = $server->label();
    }

    $config = $this->config('solrlog.settings');
    $form['server'] = [
      '#type' => 'select',
      '#required' => TRUE,
      '#options' => $options,
      '#title' => $this->t('Server'),
      '#description' => $this->t('Select a solr server to use.'),
      '#default_value' => $config->get('server'),
    ];
    if (!$options) {
      $form['warning'] = [
        '#markup' => '<p class="messages--error">' . $this->t('No solr servers found.') . '</p>',
      ];
    }
    $form['delayed_log'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Delayed log'),
      '#description' => $this->t('Log messages in a bulk in the end of the request.'),
      '#default_value' => $config->get('delayed_log'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('solrlog.settings');
    $config->set('server', $form_state->getValue('server'))
      ->set('delayed_log', $form_state->getValue('delayed_log'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
